@@ -1,10 +1,28 @@
-add_eig <- function(m1, m2) {
+add_eig <- function(m1, m2, current_rank) {
   
   #output
   out = list()
   
-  bign = m1$m + m2$m 
-  bigOrgn = ((m1$orgn * m1$m) + (m2$orgn * m2$m))/bign
+  m1$u=m1$u[,1:current_rank]
+  m1$v=m1$v[,1:current_rank]
+  m1$d=m1$d[1:current_rank]
+  m2$u=m2$u[,1:current_rank]
+
+  m2$v=m2$v[,1:current_rank]
+  m2$d=m2$d[1:current_rank]
+  
+  bign = m1$m + m2$m
+  if(is.null(m1$true_m)&is.null(m2$true_m)){
+    bigOrgn = ((m1$orgn * m1$m) + (m2$orgn * m2$m))/bign  
+  }
+  if(!is.null(m1$true_m)){
+    big_true_n = m1$true_m + m2$m
+    bigOrgn = ((as.vector(m1$orgn) * as.vector(m1$true_m)) + as.vector(m2$orgn * m2$m))/big_true_n
+  }
+  if(!is.null(m2$true_m)){
+    big_true_n = m1$m + m2$true_m
+    bigOrgn = (as.vector(m1$orgn * m1$m) + (as.vector(m2$orgn) * as.vector(m2$true_m)))/big_true_n
+  }
   
   dorgn = m1$orgn - m2$orgn
   G = t(m1$v) %*% m2$v
@@ -15,14 +33,14 @@ add_eig <- function(m1, m2) {
   HH = apply(H * H, 2, sum)
   hh = apply(h * h, 2, sum)
   #if (any(HH > eps) | any(hh > eps)) {
-    #   source("orth.r")
+  #   source("orth.r")
   #  Hnz = which(HH > eps)
   #  hnz = which(hh > eps)
   #  nu = orth(cbind(HH[, Hnz], hh[, hnz]))
   #  H = t(m1$v) %*% nu
   #  nu = nu[, -Hnz]
   #} else {
-    nu = matrix(0, length(m1$orgn), 0)
+  nu = matrix(0, length(m1$orgn), 0)
   # }
   resn1 = ncol(m1$v) - nrow(m1$v)
   #  if (resn1 > 0) {
@@ -43,23 +61,7 @@ add_eig <- function(m1, m2) {
   D = t(t(G) * as.vector(m2$d))
   E = t(t(Gamma) * as.vector(m2$d))
   gamma = t(nu) %*% dorgn
-  #   if (is.svd == F) {
-  #     chk1 = cbind(t(m1$d), rpern1 %*% matrix(1, 1, mnu))
-  #     A1 = (m1$m/bign) * diag(as.vector(chk1))
-  #     #A1try = (m1$m/bign) * (as.vector(chk1))
-  #     A21 = cbind(D %*% t(G), D %*% t(Gamma))
-  #     A22 = cbind(E %*% t(G), E %*% t(Gamma))
-  #     A2 = (m2$m/bign) * rbind(A21, A22)
-  #     A31 = cbind(g %*% t(g), g %*% t(gamma))
-  #     A32 = cbind(gamma %*% t(g), gamma %*% t(gamma))
-  #     A3 = ((as.double(m1$m) * as.double(m2$m))/(bign^2)) * rbind(A31, A32)
-  #     A = A1 + A2 + A3
-  #     A = (A + t(A))/2
-  #     eigA = eigen(A)
-  #     v = eigA$vectors
-  #     v = cbind(m1$v, nu) %*% v
-  #     d = eigA$values
-  #   } else {
+  
   A11 = cbind(m1$d * t(m1$u), G %*% (m2$d * t(m2$u)) )
   A12b = (t(nu) %*% m2$v) %*% (m2$d * t(m2$u))
   t = nrow(A12b)
@@ -73,25 +75,21 @@ add_eig <- function(m1, m2) {
   dorgnY = as.double(m2$orgn) - as.double(bigOrgn)
   A21a = (t(m1$v) %*% as.double(dorgnX) %*% onerX)
   A21b = (t(m1$v) %*% as.double(dorgnY) %*% onerY)
-  #A21b=(t(m2$v) %*% dorgnX %*% onerX) prova con Uy
+  
   A21 = cbind(A21a, A21b)
   A22a = t(nu) %*% as.double(dorgnX) %*% onerX
   A22b = t(nu) %*% as.double(dorgnY) %*% onerY
   A22 = cbind(A22a, A22b)
   A2 = rbind(A21, A22)
   A = A1 + A2
-  #library(svd)
   svd.res = fast.svd(A,0)
   
-  #   svd.res = irlba(A,nrow(A),nrow(A))
-  #svd.res = svd(A)
   v = svd.res$u
+  
   v = cbind(m1$v, nu) %*% v
-  #v=sign.matcher(m1$v,v)
   d = svd.res$d
   u = svd.res$v
   out$u = u
-  #  }
   
   out$m = bign
   out$orgn = bigOrgn
@@ -101,3 +99,5 @@ add_eig <- function(m1, m2) {
   out
 }  
 
+
+
